@@ -1589,6 +1589,7 @@
         },
         save_current: function() {
             var current_record = this.current_record;
+            let new_record = current_record.id < 0;
             if (!current_record) {
                 if (this.current_view &&
                     (this.current_view.view_type == 'tree') &&
@@ -1626,6 +1627,9 @@
                     path.splice(-1, 1,
                             [path[path.length - 1][0], current_record.id]);
                 }
+                if (new_record && this.switch_callback) {
+                    this.switch_callback();
+                }
                 return this.group.get_by_path(path).then(record => {
                     this.current_record = record;
                 });
@@ -2153,7 +2157,9 @@
                             }
                         }
                     }
-                    if ((this.views.length == 1) && this.current_record) {
+                }
+                if ((view === this.current_view) && (view.view_type == 'form')) {
+                    if (this.current_record) {
                         if (!(parent_ in this.tree_states)) {
                             this.tree_states[parent_] = {};
                         }
@@ -2169,11 +2175,13 @@
                         paths = [];
                     }
                     var selected_paths = view.get_selected_paths();
-                    if (!(parent_ in this.tree_states)) {
-                        this.tree_states[parent_] = {};
+                    if (view === this.current_view) {
+                        if (!(parent_ in this.tree_states)) {
+                            this.tree_states[parent_] = {};
+                        }
+                        this.tree_states[parent_][view.children_field || null] = [
+                            paths, selected_paths];
                     }
-                    this.tree_states[parent_][view.children_field || null] = [
-                        paths, selected_paths];
                     if (store && parseInt(view.attributes.tree_state, 10)) {
                         var tree_state_model = new Sao.Model(
                                 'ir.ui.view_tree_state');
