@@ -831,7 +831,7 @@
                 this.screen.save_tree_state();
             }
             var access = Sao.common.MODELACCESS.get(this.screen.model_name);
-            if (!(access.write || access.create)) {
+            if (this.screen.readonly || !(access.write || access.create)) {
                 return jQuery.Deferred().reject();
             }
             return this.screen.save_current().then(
@@ -901,7 +901,8 @@
             });
         },
         delete_: function() {
-            if (!Sao.common.MODELACCESS.get(this.screen.model_name)['delete']) {
+            if (!Sao.common.MODELACCESS.get(this.screen.model_name)['delete']
+                || !this.screen.deletable) {
                 return jQuery.when();
             }
             var msg;
